@@ -21,7 +21,8 @@ import org.rosuda.JGR.DataLoader;
 import org.rosuda.JGR.JGR;
 import org.rosuda.REngine.REXPMismatchException;
 import org.rosuda.REngine.REngineException;
-
+import CADStat.java.plots.SubsetFormatter;
+ 
 /**
  *
  * @author  Pasha Minallah
@@ -466,9 +467,9 @@ private void coefBioInferDataRadioButtonActionPerformed(java.awt.event.ActionEve
     String cmd = "bioinfer.JGR("
       + "bio.data=" + this.getDatasetPane().getSelectedDataset()
       + ", subset1.name=" + (this.getFactorSelectionPane1().getFactorValueList().isSelectionEmpty() ? "NULL" : "'" + this.getFactorSelectionPane1().getSelectedFactor() + "'")
-      + ", subset1.val=" + (this.getFactorSelectionPane1().getFactorValueList().isSelectionEmpty() ? "NULL" : "c(" + RUtils.toString(this.getFactorSelectionPane1().getSelectedFactorValues(), ",", "'") + ")")
+      + ", subset1.val=" + (this.getFactorSelectionPane1().getFactorValueList().isSelectionEmpty() ? "NULL" : SubsetFormatter.formatSubset(this.getFactorSelectionPane1().getSelectedFactorValues()))
       + ", subset2.name=" + (this.getFactorSelectionPane2().getFactorValueList().isSelectionEmpty() ? "NULL" : "'" + this.getFactorSelectionPane2().getSelectedFactor() + "'")
-      + ", subset2.val=" + (this.getFactorSelectionPane2().getFactorValueList().isSelectionEmpty() ? "NULL" : "c(" + RUtils.toString(this.getFactorSelectionPane2().getSelectedFactorValues(), ",", "'") + ")")
+      + ", subset2.val=" + (this.getFactorSelectionPane2().getFactorValueList().isSelectionEmpty() ? "NULL" : SubsetFormatter.formatSubset(this.getFactorSelectionPane2().getSelectedFactorValues()))
       + ", siteID=" + GUIUtils.getSelectedItemR(siteComboBox)
       + ", taxonName=" + GUIUtils.getSelectedItemR(taxonNameComboBox)
       + ", taxonCount=" + GUIUtils.getSelectedItemR(taxonCountComboBox)
